.bk-root {
  @charset "UTF-8";
  /* Functional styling;
 * These styles are required for noUiSlider to function.
 * You don't need to change these rules to apply your design.
 */
  /* Painting and performance;
 * Browsers can paint handles in their own layer.
 */
  /* Slider size and handle placement;
 */
  /* Styling;
 */
  /* Handles and cursors;
 */
  /* Handle stripes;
 */
  /* Disabled state;
 */
  /* Base;
 *
 */
  /* Values;
 *
 */
  /* Markings;
 *
 */
  /* Horizontal layout;
 *
 */
  /* Vertical layout;
 *
 */
  /*!
 * Pikaday
 * Copyright © 2014 David Bushell | BSD & MIT license | http://dbushell.com/
 */
  /*
clear child float (pika-lendar), using the famous micro clearfix hack
http://nicolasgallagher.com/micro-clearfix-hack/
*/
  /* styling for abbr */
  /* This is the line that gives everything bootstrap styling */
  /* misc */
  /* dropdown */
  /* tabs */
}
.bk-root .bk-noUi-target,
.bk-root .bk-noUi-target * {
  -webkit-touch-callout: none;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
  -webkit-user-select: none;
  -ms-touch-action: none;
  touch-action: none;
  -ms-user-select: none;
  -moz-user-select: none;
  user-select: none;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.bk-root .bk-noUi-target {
  position: relative;
  direction: ltr;
}
.bk-root .bk-noUi-base {
  width: 100%;
  height: 100%;
  position: relative;
  z-index: 1;
  /* Fix 401 */
}
.bk-root .bk-noUi-connect {
  position: absolute;
  right: 0;
  top: 0;
  left: 0;
  bottom: 0;
}
.bk-root .bk-noUi-origin {
  position: absolute;
  height: 0;
  width: 0;
}
.bk-root .bk-noUi-handle {
  position: relative;
  z-index: 1;
}
.bk-root .bk-noUi-state-tap .bk-noUi-connect,
.bk-root .bk-noUi-state-tap .bk-noUi-origin {
  -webkit-transition: top 0.3s, right 0.3s, bottom 0.3s, left 0.3s;
  transition: top 0.3s, right 0.3s, bottom 0.3s, left 0.3s;
}
.bk-root .bk-noUi-state-drag * {
  cursor: inherit !important;
}
.bk-root .bk-noUi-base,
.bk-root .bk-noUi-handle {
  -webkit-transform: translate3d(0, 0, 0);
  transform: translate3d(0, 0, 0);
}
.bk-root .bk-noUi-horizontal {
  height: 18px;
}
.bk-root .bk-noUi-horizontal .bk-noUi-handle {
  width: 34px;
  height: 28px;
  left: -17px;
  top: -6px;
}
.bk-root .bk-noUi-vertical {
  width: 18px;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle {
  width: 28px;
  height: 34px;
  left: -6px;
  top: -17px;
}
.bk-root .bk-noUi-target {
  background: #FAFAFA;
  border-radius: 4px;
  border: 1px solid #D3D3D3;
  box-shadow: inset 0 1px 1px #F0F0F0, 0 3px 6px -5px #BBB;
}
.bk-root .bk-noUi-connect {
  background: #3FB8AF;
  border-radius: 4px;
  box-shadow: inset 0 0 3px rgba(51, 51, 51, 0.45);
  -webkit-transition: background 450ms;
  transition: background 450ms;
}
.bk-root .bk-noUi-draggable {
  cursor: ew-resize;
}
.bk-root .bk-noUi-vertical .bk-noUi-draggable {
  cursor: ns-resize;
}
.bk-root .bk-noUi-handle {
  border: 1px solid #D9D9D9;
  border-radius: 3px;
  background: #FFF;
  cursor: default;
  box-shadow: inset 0 0 1px #FFF, inset 0 1px 7px #EBEBEB, 0 3px 6px -3px #BBB;
}
.bk-root .bk-noUi-active {
  box-shadow: inset 0 0 1px #FFF, inset 0 1px 7px #DDD, 0 3px 6px -3px #BBB;
}
.bk-root .bk-noUi-handle:before,
.bk-root .bk-noUi-handle:after {
  content: "";
  display: block;
  position: absolute;
  height: 14px;
  width: 1px;
  background: #E8E7E6;
  left: 14px;
  top: 6px;
}
.bk-root .bk-noUi-handle:after {
  left: 17px;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle:before,
.bk-root .bk-noUi-vertical .bk-noUi-handle:after {
  width: 14px;
  height: 1px;
  left: 6px;
  top: 14px;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle:after {
  top: 17px;
}
.bk-root [disabled] .bk-noUi-connect {
  background: #B8B8B8;
}
.bk-root [disabled].bk-noUi-target,
.bk-root [disabled].bk-noUi-handle,
.bk-root [disabled] .bk-noUi-handle {
  cursor: not-allowed;
}
.bk-root .bk-noUi-pips,
.bk-root .bk-noUi-pips * {
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.bk-root .bk-noUi-pips {
  position: absolute;
  color: #999;
}
.bk-root .bk-noUi-value {
  position: absolute;
  white-space: nowrap;
  text-align: center;
}
.bk-root .bk-noUi-value-sub {
  color: #ccc;
  font-size: 10px;
}
.bk-root .bk-noUi-marker {
  position: absolute;
  background: #CCC;
}
.bk-root .bk-noUi-marker-sub {
  background: #AAA;
}
.bk-root .bk-noUi-marker-large {
  background: #AAA;
}
.bk-root .bk-noUi-pips-horizontal {
  padding: 10px 0;
  height: 80px;
  top: 100%;
  left: 0;
  width: 100%;
}
.bk-root .bk-noUi-value-horizontal {
  -webkit-transform: translate3d(-50%, 50%, 0);
  transform: translate3d(-50%, 50%, 0);
}
.bk-root .bk-noUi-marker-horizontal.bk-noUi-marker {
  margin-left: -1px;
  width: 2px;
  height: 5px;
}
.bk-root .bk-noUi-marker-horizontal.bk-noUi-marker-sub {
  height: 10px;
}
.bk-root .bk-noUi-marker-horizontal.bk-noUi-marker-large {
  height: 15px;
}
.bk-root .bk-noUi-pips-vertical {
  padding: 0 10px;
  height: 100%;
  top: 0;
  left: 100%;
}
.bk-root .bk-noUi-value-vertical {
  -webkit-transform: translate3d(0, 50%, 0);
  transform: translate3d(0, 50%, 0);
  padding-left: 25px;
}
.bk-root .bk-noUi-marker-vertical.bk-noUi-marker {
  width: 5px;
  height: 2px;
  margin-top: -1px;
}
.bk-root .bk-noUi-marker-vertical.bk-noUi-marker-sub {
  width: 10px;
}
.bk-root .bk-noUi-marker-vertical.bk-noUi-marker-large {
  width: 15px;
}
.bk-root .bk-noUi-tooltip {
  display: block;
  position: absolute;
  border: 1px solid #D9D9D9;
  border-radius: 3px;
  background: #fff;
  color: #000;
  padding: 5px;
  text-align: center;
  white-space: nowrap;
}
.bk-root .bk-noUi-horizontal .bk-noUi-tooltip {
  -webkit-transform: translate(-50%, 0);
  transform: translate(-50%, 0);
  left: 50%;
  bottom: 120%;
}
.bk-root .bk-noUi-vertical .bk-noUi-tooltip {
  -webkit-transform: translate(0, -50%);
  transform: translate(0, -50%);
  top: 50%;
  right: 120%;
}
.bk-root .bk-noUi-handle {
  cursor: grab;
  cursor: -webkit-grab;
}
.bk-root .bk-noUi-handle.bk-noUi-active {
  cursor: grabbing;
  cursor: -webkit-grabbing;
}
.bk-root .bk-noUi-tooltip {
  display: none;
  white-space: nowrap;
}
.bk-root .bk-noUi-handle:hover .bk-noUi-tooltip {
  display: block;
}
.bk-root .bk-noUi-horizontal {
  width: 100%;
  height: 10px;
}
.bk-root .bk-noUi-horizontal .bk-noUi-handle {
  width: 14px;
  height: 18px;
  left: -7px;
  top: -5px;
}
.bk-root .bk-noUi-vertical {
  width: 10px;
  height: 100%;
}
.bk-root .bk-noUi-vertical .bk-noUi-handle {
  width: 18px;
  height: 14px;
  left: -5px;
  top: -7px;
}
.bk-root .bk-noUi-handle:after,
.bk-root .bk-noUi-handle:before {
  display: none;
}
.bk-root .bk-noUi-connect {
  box-shadow: none;
}
.bk-root fieldset {
  padding: 0;
  margin: 0;
  border: 0;
  min-width: 0;
}
.bk-root legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 17px;
  line-height: inherit;
  color: #333333;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
}
.bk-root label {
  display: inline-block;
  margin-bottom: 5px;
}
.bk-root input[type="search"] {
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.bk-root input[type="radio"],
.bk-root input[type="checkbox"] {
  margin: 4px 0 0;
  margin-top: 1px \9;
  /* IE8-9 */
  line-height: normal;
}
.bk-root input[type="file"] {
  display: block;
}
.bk-root input[type="range"] {
  display: block;
  width: 100%;
}
.bk-root select[multiple],
.bk-root select[size] {
  height: auto;
}
.bk-root input[type="file"]:focus,
.bk-root input[type="radio"]:focus,
.bk-root input[type="checkbox"]:focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.bk-root output {
  display: block;
  padding-top: 7px;
  line-height: 1.42857143;
  color: #555555;
}
.bk-root .bk-bs-form-control {
  display: block;
  height: 31px;
  padding: 0 12px;
  background-color: #fff;
  background-image: none;
  border: 1px solid #ccc;
  border-radius: 4px;
}
.bk-root .bk-bs-form-control:focus {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
}
.bk-root .bk-bs-form-control::-moz-placeholder {
  color: #999999;
  opacity: 1;
}
.bk-root .bk-bs-form-control:-ms-input-placeholder {
  color: #999999;
}
.bk-root .bk-bs-form-control::-webkit-input-placeholder {
  color: #999999;
}
.bk-root .bk-bs-form-control[disabled],
.bk-root .bk-bs-form-control[readonly],
fieldset[disabled] .bk-root .bk-bs-form-control {
  cursor: not-allowed;
  background-color: #eeeeee;
  opacity: 1;
}
textarea.bk-root .bk-bs-form-control {
  height: auto;
}
.bk-root input[type="search"] {
  -webkit-appearance: none;
}
.bk-root input[type="date"] {
  line-height: 31px;
}
.bk-root .bk-bs-form-group {
  margin-bottom: 15px;
}
.bk-root .bk-bs-radio,
.bk-root .bk-bs-checkbox {
  display: block;
  min-height: 17px;
  margin-top: 10px;
  margin-bottom: 10px;
  padding-left: 20px;
}
.bk-root .bk-bs-radio label,
.bk-root .bk-bs-checkbox label {
  display: inline;
  font-weight: normal;
  cursor: pointer;
}
.bk-root .bk-bs-radio input[type="radio"],
.bk-root .bk-bs-radio-inline input[type="radio"],
.bk-root .bk-bs-checkbox input[type="checkbox"],
.bk-root .bk-bs-checkbox-inline input[type="checkbox"] {
  float: left;
  margin-left: -20px;
}
.bk-root .bk-bs-radio + .bk-bs-radio,
.bk-root .bk-bs-checkbox + .bk-bs-checkbox {
  margin-top: -5px;
}
.bk-root .bk-bs-radio-inline,
.bk-root .bk-bs-checkbox-inline {
  display: inline-block;
  padding-left: 20px;
  margin-bottom: 0;
  vertical-align: middle;
  font-weight: normal;
  cursor: pointer;
}
.bk-root .bk-bs-radio-inline + .bk-bs-radio-inline,
.bk-root .bk-bs-checkbox-inline + .bk-bs-checkbox-inline {
  margin-top: 0;
  margin-left: 10px;
}
.bk-root input[type="radio"][disabled],
.bk-root input[type="checkbox"][disabled],
.bk-root .bk-bs-radio[disabled],
.bk-root .bk-bs-radio-inline[disabled],
.bk-root .bk-bs-checkbox[disabled],
.bk-root .bk-bs-checkbox-inline[disabled],
fieldset[disabled] .bk-root input[type="radio"],
fieldset[disabled] .bk-root input[type="checkbox"],
fieldset[disabled] .bk-root .bk-bs-radio,
fieldset[disabled] .bk-root .bk-bs-radio-inline,
fieldset[disabled] .bk-root .bk-bs-checkbox,
fieldset[disabled] .bk-root .bk-bs-checkbox-inline {
  cursor: not-allowed;
}
.bk-root .bk-bs-input-sm {
  height: 28px;
  padding: 5px 10px;
  font-size: 11px;
  line-height: 1.5;
  border-radius: 3px;
}
select.bk-root .bk-bs-input-sm {
  height: 28px;
  line-height: 28px;
}
textarea.bk-root .bk-bs-input-sm,
select[multiple].bk-root .bk-bs-input-sm {
  height: auto;
}
.bk-root .bk-bs-input-lg {
  height: 42px;
  padding: 10px 16px;
  font-size: 15px;
  line-height: 1.33;
  border-radius: 6px;
}
select.bk-root .bk-bs-input-lg {
  height: 42px;
  line-height: 42px;
}
textarea.bk-root .bk-bs-input-lg,
select[multiple].bk-root .bk-bs-input-lg {
  height: auto;
}
.bk-root .bk-bs-has-feedback {
  position: relative;
}
.bk-root .bk-bs-has-feedback .bk-bs-form-control {
  padding-right: 38.75px;
}
.bk-root .bk-bs-has-feedback .bk-bs-form-control-feedback {
  position: absolute;
  top: 22px;
  right: 0;
  display: block;
  width: 31px;
  height: 31px;
  line-height: 31px;
  text-align: center;
}
.bk-root .bk-bs-has-success .bk-bs-help-block,
.bk-root .bk-bs-has-success .bk-bs-control-label,
.bk-root .bk-bs-has-success .bk-bs-radio,
.bk-root .bk-bs-has-success .bk-bs-checkbox,
.bk-root .bk-bs-has-success .bk-bs-radio-inline,
.bk-root .bk-bs-has-success .bk-bs-checkbox-inline {
  color: #3c763d;
}
.bk-root .bk-bs-has-success .bk-bs-form-control {
  border-color: #3c763d;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.bk-root .bk-bs-has-success .bk-bs-form-control:focus {
  border-color: #2b542c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #67b168;
}
.bk-root .bk-bs-has-success .bk-bs-input-group-addon {
  color: #3c763d;
  border-color: #3c763d;
  background-color: #dff0d8;
}
.bk-root .bk-bs-has-success .bk-bs-form-control-feedback {
  color: #3c763d;
}
.bk-root .bk-bs-has-warning .bk-bs-help-block,
.bk-root .bk-bs-has-warning .bk-bs-control-label,
.bk-root .bk-bs-has-warning .bk-bs-radio,
.bk-root .bk-bs-has-warning .bk-bs-checkbox,
.bk-root .bk-bs-has-warning .bk-bs-radio-inline,
.bk-root .bk-bs-has-warning .bk-bs-checkbox-inline {
  color: #8a6d3b;
}
.bk-root .bk-bs-has-warning .bk-bs-form-control {
  border-color: #8a6d3b;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.bk-root .bk-bs-has-warning .bk-bs-form-control:focus {
  border-color: #66512c;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c0a16b;
}
.bk-root .bk-bs-has-warning .bk-bs-input-group-addon {
  color: #8a6d3b;
  border-color: #8a6d3b;
  background-color: #fcf8e3;
}
.bk-root .bk-bs-has-warning .bk-bs-form-control-feedback {
  color: #8a6d3b;
}
.bk-root .bk-bs-has-error .bk-bs-help-block,
.bk-root .bk-bs-has-error .bk-bs-control-label,
.bk-root .bk-bs-has-error .bk-bs-radio,
.bk-root .bk-bs-has-error .bk-bs-checkbox,
.bk-root .bk-bs-has-error .bk-bs-radio-inline,
.bk-root .bk-bs-has-error .bk-bs-checkbox-inline {
  color: #a94442;
}
.bk-root .bk-bs-has-error .bk-bs-form-control {
  border-color: #a94442;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}
.bk-root .bk-bs-has-error .bk-bs-form-control:focus {
  border-color: #843534;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
  box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ce8483;
}
.bk-root .bk-bs-has-error .bk-bs-input-group-addon {
  color: #a94442;
  border-color: #a94442;
  background-color: #f2dede;
}
.bk-root .bk-bs-has-error .bk-bs-form-control-feedback {
  color: #a94442;
}
.bk-root .bk-bs-form-control-static {
  margin-bottom: 0;
}
.bk-root .bk-bs-help-block {
  display: block;
  margin-top: 5px;
  margin-bottom: 10px;
  color: #737373;
}
@media (min-width: 768px) {
  .bk-root .bk-bs-form-inline .bk-bs-form-group {
    display: inline-block;
    margin-bottom: 0;
    vertical-align: middle;
  }
  .bk-root .bk-bs-form-inline .bk-bs-form-control {
    display: inline-block;
    width: auto;
    vertical-align: middle;
  }
  .bk-root .bk-bs-form-inline .bk-bs-input-group > .bk-bs-form-control {
    width: 100%;
  }
  .bk-root .bk-bs-form-inline .bk-bs-control-label {
    margin-bottom: 0;
    vertical-align: middle;
  }
  .bk-root .bk-bs-form-inline .bk-bs-radio,
  .bk-root .bk-bs-form-inline .bk-bs-checkbox {
    display: inline-block;
    margin-top: 0;
    margin-bottom: 0;
    padding-left: 0;
    vertical-align: middle;
  }
  .bk-root .bk-bs-form-inline .bk-bs-radio input[type="radio"],
  .bk-root .bk-bs-form-inline .bk-bs-checkbox input[type="checkbox"] {
    float: none;
    margin-left: 0;
  }
  .bk-root .bk-bs-form-inline .bk-bs-has-feedback .bk-bs-form-control-feedback {
    top: 0;
  }
}
.bk-root .bk-bs-form-horizontal .bk-bs-control-label,
.bk-root .bk-bs-form-horizontal .bk-bs-radio,
.bk-root .bk-bs-form-horizontal .bk-bs-checkbox,
.bk-root .bk-bs-form-horizontal .bk-bs-radio-inline,
.bk-root .bk-bs-form-horizontal .bk-bs-checkbox-inline {
  margin-top: 0;
  margin-bottom: 0;
  padding-top: 7px;
}
.bk-root .bk-bs-form-horizontal .bk-bs-radio,
.bk-root .bk-bs-form-horizontal .bk-bs-checkbox {
  min-height: 24px;
}
.bk-root .bk-bs-form-horizontal .bk-bs-form-group {
  margin-left: -15px;
  margin-right: -15px;
}
.bk-root .bk-bs-form-horizontal .bk-bs-form-control-static {
  padding-top: 7px;
}
@media (min-width: 768px) {
  .bk-root .bk-bs-form-horizontal .bk-bs-control-label {
    text-align: right;
  }
}
.bk-root .bk-bs-form-horizontal .bk-bs-has-feedback .bk-bs-form-control-feedback {
  top: 0;
  right: 15px;
}
.bk-root .bk-bs-btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  vertical-align: middle;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  white-space: nowrap;
  padding: 6px 12px;
  font-size: 12px;
  line-height: 1.42857143;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.bk-root .bk-bs-btn:focus,
.bk-root .bk-bs-btn:active:focus,
.bk-root .bk-bs-btn.bk-bs-active:focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
.bk-root .bk-bs-btn:hover,
.bk-root .bk-bs-btn:focus {
  color: #333;
  text-decoration: none;
}
.bk-root .bk-bs-btn:active,
.bk-root .bk-bs-btn.bk-bs-active {
  outline: 0;
  background-image: none;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.bk-root .bk-bs-btn.bk-bs-disabled,
.bk-root .bk-bs-btn[disabled],
fieldset[disabled] .bk-root .bk-bs-btn {
  cursor: not-allowed;
  pointer-events: none;
  opacity: 0.65;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
  box-shadow: none;
}
.bk-root .bk-bs-btn-default {
  color: #333;
  background-color: #fff;
  border-color: #ccc;
}
.bk-root .bk-bs-btn-default:hover,
.bk-root .bk-bs-btn-default:focus,
.bk-root .bk-bs-btn-default:active,
.bk-root .bk-bs-btn-default.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-default {
  color: #333;
  background-color: #ebebeb;
  border-color: #adadad;
}
.bk-root .bk-bs-btn-default:active,
.bk-root .bk-bs-btn-default.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-default {
  background-image: none;
}
.bk-root .bk-bs-btn-default.bk-bs-disabled,
.bk-root .bk-bs-btn-default[disabled],
fieldset[disabled] .bk-root .bk-bs-btn-default,
.bk-root .bk-bs-btn-default.bk-bs-disabled:hover,
.bk-root .bk-bs-btn-default[disabled]:hover,
fieldset[disabled] .bk-root .bk-bs-btn-default:hover,
.bk-root .bk-bs-btn-default.bk-bs-disabled:focus,
.bk-root .bk-bs-btn-default[disabled]:focus,
fieldset[disabled] .bk-root .bk-bs-btn-default:focus,
.bk-root .bk-bs-btn-default.bk-bs-disabled:active,
.bk-root .bk-bs-btn-default[disabled]:active,
fieldset[disabled] .bk-root .bk-bs-btn-default:active,
.bk-root .bk-bs-btn-default.bk-bs-disabled.bk-bs-active,
.bk-root .bk-bs-btn-default[disabled].bk-bs-active,
fieldset[disabled] .bk-root .bk-bs-btn-default.bk-bs-active {
  background-color: #fff;
  border-color: #ccc;
}
.bk-root .bk-bs-btn-default .bk-bs-badge {
  color: #fff;
  background-color: #333;
}
.bk-root .bk-bs-btn-primary {
  color: #fff;
  background-color: #428bca;
  border-color: #357ebd;
}
.bk-root .bk-bs-btn-primary:hover,
.bk-root .bk-bs-btn-primary:focus,
.bk-root .bk-bs-btn-primary:active,
.bk-root .bk-bs-btn-primary.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-primary {
  color: #fff;
  background-color: #3276b1;
  border-color: #285e8e;
}
.bk-root .bk-bs-btn-primary:active,
.bk-root .bk-bs-btn-primary.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-primary {
  background-image: none;
}
.bk-root .bk-bs-btn-primary.bk-bs-disabled,
.bk-root .bk-bs-btn-primary[disabled],
fieldset[disabled] .bk-root .bk-bs-btn-primary,
.bk-root .bk-bs-btn-primary.bk-bs-disabled:hover,
.bk-root .bk-bs-btn-primary[disabled]:hover,
fieldset[disabled] .bk-root .bk-bs-btn-primary:hover,
.bk-root .bk-bs-btn-primary.bk-bs-disabled:focus,
.bk-root .bk-bs-btn-primary[disabled]:focus,
fieldset[disabled] .bk-root .bk-bs-btn-primary:focus,
.bk-root .bk-bs-btn-primary.bk-bs-disabled:active,
.bk-root .bk-bs-btn-primary[disabled]:active,
fieldset[disabled] .bk-root .bk-bs-btn-primary:active,
.bk-root .bk-bs-btn-primary.bk-bs-disabled.bk-bs-active,
.bk-root .bk-bs-btn-primary[disabled].bk-bs-active,
fieldset[disabled] .bk-root .bk-bs-btn-primary.bk-bs-active {
  background-color: #428bca;
  border-color: #357ebd;
}
.bk-root .bk-bs-btn-primary .bk-bs-badge {
  color: #428bca;
  background-color: #fff;
}
.bk-root .bk-bs-btn-success {
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.bk-root .bk-bs-btn-success:hover,
.bk-root .bk-bs-btn-success:focus,
.bk-root .bk-bs-btn-success:active,
.bk-root .bk-bs-btn-success.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-success {
  color: #fff;
  background-color: #47a447;
  border-color: #398439;
}
.bk-root .bk-bs-btn-success:active,
.bk-root .bk-bs-btn-success.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-success {
  background-image: none;
}
.bk-root .bk-bs-btn-success.bk-bs-disabled,
.bk-root .bk-bs-btn-success[disabled],
fieldset[disabled] .bk-root .bk-bs-btn-success,
.bk-root .bk-bs-btn-success.bk-bs-disabled:hover,
.bk-root .bk-bs-btn-success[disabled]:hover,
fieldset[disabled] .bk-root .bk-bs-btn-success:hover,
.bk-root .bk-bs-btn-success.bk-bs-disabled:focus,
.bk-root .bk-bs-btn-success[disabled]:focus,
fieldset[disabled] .bk-root .bk-bs-btn-success:focus,
.bk-root .bk-bs-btn-success.bk-bs-disabled:active,
.bk-root .bk-bs-btn-success[disabled]:active,
fieldset[disabled] .bk-root .bk-bs-btn-success:active,
.bk-root .bk-bs-btn-success.bk-bs-disabled.bk-bs-active,
.bk-root .bk-bs-btn-success[disabled].bk-bs-active,
fieldset[disabled] .bk-root .bk-bs-btn-success.bk-bs-active {
  background-color: #5cb85c;
  border-color: #4cae4c;
}
.bk-root .bk-bs-btn-success .bk-bs-badge {
  color: #5cb85c;
  background-color: #fff;
}
.bk-root .bk-bs-btn-info {
  color: #fff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
.bk-root .bk-bs-btn-info:hover,
.bk-root .bk-bs-btn-info:focus,
.bk-root .bk-bs-btn-info:active,
.bk-root .bk-bs-btn-info.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-info {
  color: #fff;
  background-color: #39b3d7;
  border-color: #269abc;
}
.bk-root .bk-bs-btn-info:active,
.bk-root .bk-bs-btn-info.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-info {
  background-image: none;
}
.bk-root .bk-bs-btn-info.bk-bs-disabled,
.bk-root .bk-bs-btn-info[disabled],
fieldset[disabled] .bk-root .bk-bs-btn-info,
.bk-root .bk-bs-btn-info.bk-bs-disabled:hover,
.bk-root .bk-bs-btn-info[disabled]:hover,
fieldset[disabled] .bk-root .bk-bs-btn-info:hover,
.bk-root .bk-bs-btn-info.bk-bs-disabled:focus,
.bk-root .bk-bs-btn-info[disabled]:focus,
fieldset[disabled] .bk-root .bk-bs-btn-info:focus,
.bk-root .bk-bs-btn-info.bk-bs-disabled:active,
.bk-root .bk-bs-btn-info[disabled]:active,
fieldset[disabled] .bk-root .bk-bs-btn-info:active,
.bk-root .bk-bs-btn-info.bk-bs-disabled.bk-bs-active,
.bk-root .bk-bs-btn-info[disabled].bk-bs-active,
fieldset[disabled] .bk-root .bk-bs-btn-info.bk-bs-active {
  background-color: #5bc0de;
  border-color: #46b8da;
}
.bk-root .bk-bs-btn-info .bk-bs-badge {
  color: #5bc0de;
  background-color: #fff;
}
.bk-root .bk-bs-btn-warning {
  color: #fff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
.bk-root .bk-bs-btn-warning:hover,
.bk-root .bk-bs-btn-warning:focus,
.bk-root .bk-bs-btn-warning:active,
.bk-root .bk-bs-btn-warning.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-warning {
  color: #fff;
  background-color: #ed9c28;
  border-color: #d58512;
}
.bk-root .bk-bs-btn-warning:active,
.bk-root .bk-bs-btn-warning.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-warning {
  background-image: none;
}
.bk-root .bk-bs-btn-warning.bk-bs-disabled,
.bk-root .bk-bs-btn-warning[disabled],
fieldset[disabled] .bk-root .bk-bs-btn-warning,
.bk-root .bk-bs-btn-warning.bk-bs-disabled:hover,
.bk-root .bk-bs-btn-warning[disabled]:hover,
fieldset[disabled] .bk-root .bk-bs-btn-warning:hover,
.bk-root .bk-bs-btn-warning.bk-bs-disabled:focus,
.bk-root .bk-bs-btn-warning[disabled]:focus,
fieldset[disabled] .bk-root .bk-bs-btn-warning:focus,
.bk-root .bk-bs-btn-warning.bk-bs-disabled:active,
.bk-root .bk-bs-btn-warning[disabled]:active,
fieldset[disabled] .bk-root .bk-bs-btn-warning:active,
.bk-root .bk-bs-btn-warning.bk-bs-disabled.bk-bs-active,
.bk-root .bk-bs-btn-warning[disabled].bk-bs-active,
fieldset[disabled] .bk-root .bk-bs-btn-warning.bk-bs-active {
  background-color: #f0ad4e;
  border-color: #eea236;
}
.bk-root .bk-bs-btn-warning .bk-bs-badge {
  color: #f0ad4e;
  background-color: #fff;
}
.bk-root .bk-bs-btn-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
.bk-root .bk-bs-btn-danger:hover,
.bk-root .bk-bs-btn-danger:focus,
.bk-root .bk-bs-btn-danger:active,
.bk-root .bk-bs-btn-danger.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-danger {
  color: #fff;
  background-color: #d2322d;
  border-color: #ac2925;
}
.bk-root .bk-bs-btn-danger:active,
.bk-root .bk-bs-btn-danger.bk-bs-active,
.bk-bs-open .bk-bs-dropdown-toggle.bk-root .bk-bs-btn-danger {
  background-image: none;
}
.bk-root .bk-bs-btn-danger.bk-bs-disabled,
.bk-root .bk-bs-btn-danger[disabled],
fieldset[disabled] .bk-root .bk-bs-btn-danger,
.bk-root .bk-bs-btn-danger.bk-bs-disabled:hover,
.bk-root .bk-bs-btn-danger[disabled]:hover,
fieldset[disabled] .bk-root .bk-bs-btn-danger:hover,
.bk-root .bk-bs-btn-danger.bk-bs-disabled:focus,
.bk-root .bk-bs-btn-danger[disabled]:focus,
fieldset[disabled] .bk-root .bk-bs-btn-danger:focus,
.bk-root .bk-bs-btn-danger.bk-bs-disabled:active,
.bk-root .bk-bs-btn-danger[disabled]:active,
fieldset[disabled] .bk-root .bk-bs-btn-danger:active,
.bk-root .bk-bs-btn-danger.bk-bs-disabled.bk-bs-active,
.bk-root .bk-bs-btn-danger[disabled].bk-bs-active,
fieldset[disabled] .bk-root .bk-bs-btn-danger.bk-bs-active {
  background-color: #d9534f;
  border-color: #d43f3a;
}
.bk-root .bk-bs-btn-danger .bk-bs-badge {
  color: #d9534f;
  background-color: #fff;
}
.bk-root .bk-bs-btn-link {
  color: #428bca;
  font-weight: normal;
  cursor: pointer;
  border-radius: 0;
}
.bk-root .bk-bs-btn-link,
.bk-root .bk-bs-btn-link:active,
.bk-root .bk-bs-btn-link[disabled],
fieldset[disabled] .bk-root .bk-bs-btn-link {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
.bk-root .bk-bs-btn-link,
.bk-root .bk-bs-btn-link:hover,
.bk-root .bk-bs-btn-link:focus,
.bk-root .bk-bs-btn-link:active {
  border-color: transparent;
}
.bk-root .bk-bs-btn-link:hover,
.bk-root .bk-bs-btn-link:focus {
  color: #2a6496;
  text-decoration: underline;
  background-color: transparent;
}
.bk-root .bk-bs-btn-link[disabled]:hover,
fieldset[disabled] .bk-root .bk-bs-btn-link:hover,
.bk-root .bk-bs-btn-link[disabled]:focus,
fieldset[disabled] .bk-root .bk-bs-btn-link:focus {
  color: #999999;
  text-decoration: none;
}
.bk-root .bk-bs-btn-lg {
  padding: 10px 16px;
  font-size: 15px;
  line-height: 1.33;
  border-radius: 6px;
}
.bk-root .bk-bs-btn-sm {
  padding: 5px 10px;
  font-size: 11px;
  line-height: 1.5;
  border-radius: 3px;
}
.bk-root .bk-bs-btn-xs {
  padding: 1px 5px;
  font-size: 11px;
  line-height: 1.5;
  border-radius: 3px;
}
.bk-root .bk-bs-btn-block {
  display: block;
  width: 100%;
  padding-left: 0;
  padding-right: 0;
}
.bk-root .bk-bs-btn-block + .bk-bs-btn-block {
  margin-top: 5px;
}
.bk-root input[type="submit"].bk-bs-btn-block,
.bk-root input[type="reset"].bk-bs-btn-block,
.bk-root input[type="button"].bk-bs-btn-block {
  width: 100%;
}
.bk-root .bk-bs-caret {
  display: inline-block;
  width: 0;
  height: 0;
  margin-left: 2px;
  vertical-align: middle;
  border-top: 4px solid;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
}
.bk-root .bk-bs-dropdown {
  position: relative;
}
.bk-root .bk-bs-dropdown-toggle:focus {
  outline: 0;
}
.bk-root .bk-bs-dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  list-style: none;
  font-size: 12px;
  background-color: #fff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 4px;
  -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  background-clip: padding-box;
}
.bk-root .bk-bs-dropdown-menu.bk-bs-pull-right {
  right: 0;
  left: auto;
}
.bk-root .bk-bs-dropdown-menu .bk-bs-divider {
  height: 1px;
  margin: 7.5px 0;
  overflow: hidden;
  background-color: #e5e5e5;
}
.bk-root .bk-bs-dropdown-menu > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 1.42857143;
  color: #333333;
  white-space: nowrap;
}
.bk-root .bk-bs-dropdown-menu > li > a:hover,
.bk-root .bk-bs-dropdown-menu > li > a:focus {
  text-decoration: none;
  color: #262626;
  background-color: #f5f5f5;
}
.bk-root .bk-bs-dropdown-menu > .bk-bs-active > a,
.bk-root .bk-bs-dropdown-menu > .bk-bs-active > a:hover,
.bk-root .bk-bs-dropdown-menu > .bk-bs-active > a:focus {
  color: #fff;
  text-decoration: none;
  outline: 0;
  background-color: #428bca;
}
.bk-root .bk-bs-dropdown-menu > .bk-bs-disabled > a,
.bk-root .bk-bs-dropdown-menu > .bk-bs-disabled > a:hover,
.bk-root .bk-bs-dropdown-menu > .bk-bs-disabled > a:focus {
  color: #999999;
}
.bk-root .bk-bs-dropdown-menu > .bk-bs-disabled > a:hover,
.bk-root .bk-bs-dropdown-menu > .bk-bs-disabled > a:focus {
  text-decoration: none;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.bk-bs-Microsoft.bk-bs-gradient(enabled = false);
  cursor: not-allowed;
}
.bk-root .bk-bs-open > .bk-bs-dropdown-menu {
  display: block;
}
.bk-root .bk-bs-open > a {
  outline: 0;
}
.bk-root .bk-bs-dropdown-menu-right {
  left: auto;
  right: 0;
}
.bk-root .bk-bs-dropdown-menu-left {
  left: 0;
  right: auto;
}
.bk-root .bk-bs-dropdown-header {
  display: block;
  padding: 3px 20px;
  font-size: 11px;
  line-height: 1.42857143;
  color: #999999;
}
.bk-root .bk-bs-dropdown-backdrop {
  position: fixed;
  left: 0;
  right: 0;
  bottom: 0;
  top: 0;
  z-index: 990;
}
.bk-root .bk-bs-pull-right > .bk-bs-dropdown-menu {
  right: 0;
  left: auto;
}
.bk-root .bk-bs-dropup .bk-bs-caret,
.bk-root .bk-bs-navbar-fixed-bottom .bk-bs-dropdown .bk-bs-caret {
  border-top: 0;
  border-bottom: 4px solid;
  content: "";
}
.bk-root .bk-bs-dropup .bk-bs-dropdown-menu,
.bk-root .bk-bs-navbar-fixed-bottom .bk-bs-dropdown .bk-bs-dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 1px;
}
@media (min-width: 768px) {
  .bk-root .bk-bs-navbar-right .bk-bs-dropdown-menu {
    left: auto;
    right: 0;
  }
  .bk-root .bk-bs-navbar-right .bk-bs-dropdown-menu-left {
    left: 0;
    right: auto;
  }
}
.bk-root .bk-bs-btn-group,
.bk-root .bk-bs-btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn {
  position: relative;
  float: left;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn:hover,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn:hover,
.bk-root .bk-bs-btn-group > .bk-bs-btn:focus,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn:focus,
.bk-root .bk-bs-btn-group > .bk-bs-btn:active,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn:active,
.bk-root .bk-bs-btn-group > .bk-bs-btn.bk-bs-active,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn.bk-bs-active {
  z-index: 2;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn:focus,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn:focus {
  outline: none;
}
.bk-root .bk-bs-btn-group .bk-bs-btn + .bk-bs-btn,
.bk-root .bk-bs-btn-group .bk-bs-btn + .bk-bs-btn-group,
.bk-root .bk-bs-btn-group .bk-bs-btn-group + .bk-bs-btn,
.bk-root .bk-bs-btn-group .bk-bs-btn-group + .bk-bs-btn-group {
  margin-left: -1px;
}
.bk-root .bk-bs-btn-toolbar {
  margin-left: -5px;
}
.bk-root .bk-bs-btn-toolbar .bk-bs-btn-group,
.bk-root .bk-bs-btn-toolbar .bk-bs-input-group {
  float: left;
}
.bk-root .bk-bs-btn-toolbar > .bk-bs-btn,
.bk-root .bk-bs-btn-toolbar > .bk-bs-btn-group,
.bk-root .bk-bs-btn-toolbar > .bk-bs-input-group {
  margin-left: 5px;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn:not(:first-child):not(:last-child):not(.bk-bs-dropdown-toggle) {
  border-radius: 0;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn:first-child {
  margin-left: 0;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn:first-child:not(:last-child):not(.bk-bs-dropdown-toggle) {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn:last-child:not(:first-child),
.bk-root .bk-bs-btn-group > .bk-bs-dropdown-toggle:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn-group {
  float: left;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn-group:not(:first-child):not(:last-child) > .bk-bs-btn {
  border-radius: 0;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn-group:first-child > .bk-bs-btn:last-child,
.bk-root .bk-bs-btn-group > .bk-bs-btn-group:first-child > .bk-bs-dropdown-toggle {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn-group:last-child > .bk-bs-btn:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.bk-root .bk-bs-btn-group .bk-bs-dropdown-toggle:active,
.bk-root .bk-bs-btn-group.bk-bs-open .bk-bs-dropdown-toggle {
  outline: 0;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn + .bk-bs-dropdown-toggle {
  padding-left: 8px;
  padding-right: 8px;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn-lg + .bk-bs-dropdown-toggle {
  padding-left: 12px;
  padding-right: 12px;
}
.bk-root .bk-bs-btn-group.bk-bs-open .bk-bs-dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
.bk-root .bk-bs-btn-group.bk-bs-open .bk-bs-dropdown-toggle.bk-bs-btn-link {
  -webkit-box-shadow: none;
  box-shadow: none;
}
.bk-root .bk-bs-btn .bk-bs-caret {
  margin-left: 0;
}
.bk-root .bk-bs-btn-lg .bk-bs-caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0;
}
.bk-root .bk-bs-dropup .bk-bs-btn-lg .bk-bs-caret {
  border-width: 0 5px 5px;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group > .bk-bs-btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group > .bk-bs-btn {
  float: none;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn + .bk-bs-btn,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn + .bk-bs-btn-group,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group + .bk-bs-btn,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group + .bk-bs-btn-group {
  margin-top: -1px;
  margin-left: 0;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn:not(:first-child):not(:last-child) {
  border-radius: 0;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn:first-child:not(:last-child) {
  border-top-right-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn:last-child:not(:first-child) {
  border-bottom-left-radius: 4px;
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group:not(:first-child):not(:last-child) > .bk-bs-btn {
  border-radius: 0;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group:first-child:not(:last-child) > .bk-bs-btn:last-child,
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group:first-child:not(:last-child) > .bk-bs-dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
.bk-root .bk-bs-btn-group-vertical > .bk-bs-btn-group:last-child:not(:first-child) > .bk-bs-btn:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}
.bk-root .bk-bs-btn-group-justified {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate;
}
.bk-root .bk-bs-btn-group-justified > .bk-bs-btn,
.bk-root .bk-bs-btn-group-justified > .bk-bs-btn-group {
  float: none;
  display: table-cell;
  width: 1%;
}
.bk-root .bk-bs-btn-group-justified > .bk-bs-btn-group .bk-bs-btn {
  width: 100%;
}
.bk-root .bk-bs-btn-group > .bk-bs-btn > input[type="radio"],
.bk-root .bk-bs-btn-group > .bk-bs-btn > input[type="checkbox"] {
  display: none;
}
.bk-root .bk-bs-input-group {
  position: relative;
  display: table;
  border-collapse: separate;
}
.bk-root .bk-bs-input-group[class*="col-"] {
  float: none;
  padding-left: 0;
  padding-right: 0;
}
.bk-root .bk-bs-input-group .bk-bs-form-control {
  position: relative;
  z-index: 2;
  float: left;
  width: 100%;
  margin-bottom: 0;
}
.bk-root .bk-bs-input-group-lg > .bk-bs-form-control,
.bk-root .bk-bs-input-group-lg > .bk-bs-input-group-addon,
.bk-root .bk-bs-input-group-lg > .bk-bs-input-group-btn > .bk-bs-btn {
  height: 42px;
  padding: 10px 16px;
  font-size: 15px;
  line-height: 1.33;
  border-radius: 6px;
}
select.bk-root .bk-bs-input-group-lg > .bk-bs-form-control,
select.bk-root .bk-bs-input-group-lg > .bk-bs-input-group-addon,
select.bk-root .bk-bs-input-group-lg > .bk-bs-input-group-btn > .bk-bs-btn {
  height: 42px;
  line-height: 42px;
}
textarea.bk-root .bk-bs-input-group-lg > .bk-bs-form-control,
textarea.bk-root .bk-bs-input-group-lg > .bk-bs-input-group-addon,
textarea.bk-root .bk-bs-input-group-lg > .bk-bs-input-group-btn > .bk-bs-btn,
select[multiple].bk-root .bk-bs-input-group-lg > .bk-bs-form-control,
select[multiple].bk-root .bk-bs-input-group-lg > .bk-bs-input-group-addon,
select[multiple].bk-root .bk-bs-input-group-lg > .bk-bs-input-group-btn > .bk-bs-btn {
  height: auto;
}
.bk-root .bk-bs-input-group-sm > .bk-bs-form-control,
.bk-root .bk-bs-input-group-sm > .bk-bs-input-group-addon,
.bk-root .bk-bs-input-group-sm > .bk-bs-input-group-btn > .bk-bs-btn {
  height: 28px;
  padding: 5px 10px;
  font-size: 11px;
  line-height: 1.5;
  border-radius: 3px;
}
select.bk-root .bk-bs-input-group-sm > .bk-bs-form-control,
select.bk-root .bk-bs-input-group-sm > .bk-bs-input-group-addon,
select.bk-root .bk-bs-input-group-sm > .bk-bs-input-group-btn > .bk-bs-btn {
  height: 28px;
  line-height: 28px;
}
textarea.bk-root .bk-bs-input-group-sm > .bk-bs-form-control,
textarea.bk-root .bk-bs-input-group-sm > .bk-bs-input-group-addon,
textarea.bk-root .bk-bs-input-group-sm > .bk-bs-input-group-btn > .bk-bs-btn,
select[multiple].bk-root .bk-bs-input-group-sm > .bk-bs-form-control,
select[multiple].bk-root .bk-bs-input-group-sm > .bk-bs-input-group-addon,
select[multiple].bk-root .bk-bs-input-group-sm > .bk-bs-input-group-btn > .bk-bs-btn {
  height: auto;
}
.bk-root .bk-bs-input-group-addon,
.bk-root .bk-bs-input-group-btn,
.bk-root .bk-bs-input-group .bk-bs-form-control {
  display: table-cell;
}
.bk-root .bk-bs-input-group-addon:not(:first-child):not(:last-child),
.bk-root .bk-bs-input-group-btn:not(:first-child):not(:last-child),
.bk-root .bk-bs-input-group .bk-bs-form-control:not(:first-child):not(:last-child) {
  border-radius: 0;
}
.bk-root .bk-bs-input-group-addon,
.bk-root .bk-bs-input-group-btn {
  width: 1%;
  white-space: nowrap;
  vertical-align: middle;
}
.bk-root .bk-bs-input-group-addon {
  padding: 6px 12px;
  font-size: 12px;
  font-weight: normal;
  line-height: 1;
  color: #555555;
  text-align: center;
  background-color: #eeeeee;
  border: 1px solid #ccc;
  border-radius: 4px;
}
.bk-root .bk-bs-input-group-addon.bk-bs-input-sm {
  padding: 5px 10px;
  font-size: 11px;
  border-radius: 3px;
}
.bk-root .bk-bs-input-group-addon.bk-bs-input-lg {
  padding: 10px 16px;
  font-size: 15px;
  border-radius: 6px;
}
.bk-root .bk-bs-input-group-addon input[type="radio"],
.bk-root .bk-bs-input-group-addon input[type="checkbox"] {
  margin-top: 0;
}
.bk-root .bk-bs-input-group .bk-bs-form-control:first-child,
.bk-root .bk-bs-input-group-addon:first-child,
.bk-root .bk-bs-input-group-btn:first-child > .bk-bs-btn,
.bk-root .bk-bs-input-group-btn:first-child > .bk-bs-btn-group > .bk-bs-btn,
.bk-root .bk-bs-input-group-btn:first-child > .bk-bs-dropdown-toggle,
.bk-root .bk-bs-input-group-btn:last-child > .bk-bs-btn:not(:last-child):not(.bk-bs-dropdown-toggle),
.bk-root .bk-bs-input-group-btn:last-child > .bk-bs-btn-group:not(:last-child) > .bk-bs-btn {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}
.bk-root .bk-bs-input-group-addon:first-child {
  border-right: 0;
}
.bk-root .bk-bs-input-group .bk-bs-form-control:last-child,
.bk-root .bk-bs-input-group-addon:last-child,
.bk-root .bk-bs-input-group-btn:last-child > .bk-bs-btn,
.bk-root .bk-bs-input-group-btn:last-child > .bk-bs-btn-group > .bk-bs-btn,
.bk-root .bk-bs-input-group-btn:last-child > .bk-bs-dropdown-toggle,
.bk-root .bk-bs-input-group-btn:first-child > .bk-bs-btn:not(:first-child),
.bk-root .bk-bs-input-group-btn:first-child > .bk-bs-btn-group:not(:first-child) > .bk-bs-btn {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}
.bk-root .bk-bs-input-group-addon:last-child {
  border-left: 0;
}
.bk-root .bk-bs-input-group-btn {
  position: relative;
  font-size: 0;
  white-space: nowrap;
}
.bk-root .bk-bs-input-group-btn > .bk-bs-btn {
  position: relative;
}
.bk-root .bk-bs-input-group-btn > .bk-bs-btn + .bk-bs-btn {
  margin-left: -1px;
}
.bk-root .bk-bs-input-group-btn > .bk-bs-btn:hover,
.bk-root .bk-bs-input-group-btn > .bk-bs-btn:focus,
.bk-root .bk-bs-input-group-btn > .bk-bs-btn:active {
  z-index: 2;
}
.bk-root .bk-bs-input-group-btn:first-child > .bk-bs-btn,
.bk-root .bk-bs-input-group-btn:first-child > .bk-bs-btn-group {
  margin-right: -1px;
}
.bk-root .bk-bs-input-group-btn:last-child > .bk-bs-btn,
.bk-root .bk-bs-input-group-btn:last-child > .bk-bs-btn-group {
  margin-left: -1px;
}
.bk-root .bk-bs-nav {
  margin-bottom: 0;
  padding-left: 0;
  list-style: none;
}
.bk-root .bk-bs-nav > li {
  position: relative;
  display: block;
}
.bk-root .bk-bs-nav > li > span {
  position: relative;
  display: block;
  padding: 10px 15px;
}
.bk-root .bk-bs-nav > li > span:hover,
.bk-root .bk-bs-nav > li > span:focus {
  text-decoration: none;
  background-color: #eeeeee;
}
.bk-root .bk-bs-nav > li.bk-bs-disabled > span {
  color: #999999;
}
.bk-root .bk-bs-nav > li.bk-bs-disabled > span:hover,
.bk-root .bk-bs-nav > li.bk-bs-disabled > span:focus {
  color: #999999;
  text-decoration: none;
  background-color: transparent;
  cursor: not-allowed;
}
.bk-root .bk-bs-nav-tabs {
  border-bottom: 1px solid #ddd;
}
.bk-root .bk-bs-nav-tabs > li {
  float: left;
  margin-bottom: -1px;
}
.bk-root .bk-bs-nav-tabs > li > span {
  margin-right: 2px;
  line-height: 1.42857143;
  border: 1px solid transparent;
  border-radius: 4px 4px 0 0;
}
.bk-root .bk-bs-nav-tabs > li > span:hover {
  border-color: #eeeeee #eeeeee #ddd;
  cursor: pointer;
}
.bk-root .bk-bs-nav-tabs > li.bk-bs-active > span,
.bk-root .bk-bs-nav-tabs > li.bk-bs-active > span:hover,
.bk-root .bk-bs-nav-tabs > li.bk-bs-active > span:focus {
  color: #555555;
  background-color: #fff;
  border: 1px solid #ddd;
  border-bottom-color: transparent;
  cursor: default;
}
.bk-root .bk-bs-tab-content > .bk-bs-tab-pane {
  display: none;
}
.bk-root .bk-bs-tab-content > .bk-bs-active {
  display: block;
}
.bk-root .pika-single {
  z-index: 9999;
  display: block;
  position: relative;
  color: #333;
  background: #fff;
  border: 1px solid #ccc;
  border-bottom-color: #bbb;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}
.bk-root .pika-single:before,
.bk-root .pika-single:after {
  content: " ";
  display: table;
}
.bk-root .pika-single:after {
  clear: both;
}
.bk-root .pika-single {
  *zoom: 1;
}
.bk-root .pika-single.is-hidden {
  display: none;
}
.bk-root .pika-single.is-bound {
  position: absolute;
  box-shadow: 0 5px 15px -5px rgba(0, 0, 0, 0.5);
}
.bk-root .pika-lendar {
  float: left;
  width: 240px;
  margin: 8px;
}
.bk-root .pika-title {
  position: relative;
  text-align: center;
}
.bk-root .pika-label {
  display: inline-block;
  *display: inline;
  position: relative;
  z-index: 9999;
  overflow: hidden;
  margin: 0;
  padding: 5px 3px;
  font-size: 14px;
  line-height: 20px;
  font-weight: bold;
  background-color: #fff;
}
.bk-root .pika-title select {
  cursor: pointer;
  position: absolute;
  z-index: 9998;
  margin: 0;
  left: 0;
  top: 5px;
  filter: alpha(opacity=0);
  opacity: 0;
}
.bk-root .pika-prev,
.bk-root .pika-next {
  display: block;
  cursor: pointer;
  position: relative;
  outline: none;
  border: 0;
  padding: 0;
  width: 20px;
  height: 30px;
  /* hide text using text-indent trick, using width value (it's enough) */
  text-indent: 20px;
  white-space: nowrap;
  overflow: hidden;
  background-color: transparent;
  background-position: center center;
  background-repeat: no-repeat;
  background-size: 75% 75%;
  opacity: .5;
  *position: absolute;
  *top: 0;
}
.bk-root .pika-prev:hover,
.bk-root .pika-next:hover {
  opacity: 1;
}
.bk-root .pika-prev,
.bk-root .is-rtl .pika-next {
  float: left;
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAUklEQVR42u3VMQoAIBADQf8Pgj+OD9hG2CtONJB2ymQkKe0HbwAP0xucDiQWARITIDEBEnMgMQ8S8+AqBIl6kKgHiXqQqAeJepBo/z38J/U0uAHlaBkBl9I4GwAAAABJRU5ErkJggg==');
  *left: 0;
}
.bk-root .pika-next,
.bk-root .is-rtl .pika-prev {
  float: right;
  background-image: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABQAAAAeCAYAAAAsEj5rAAAAU0lEQVR42u3VOwoAMAgE0dwfAnNjU26bYkBCFGwfiL9VVWoO+BJ4Gf3gtsEKKoFBNTCoCAYVwaAiGNQGMUHMkjGbgjk2mIONuXo0nC8XnCf1JXgArVIZAQh5TKYAAAAASUVORK5CYII=');
  *right: 0;
}
.bk-root .pika-prev.is-disabled,
.bk-root .pika-next.is-disabled {
  cursor: default;
  opacity: .2;
}
.bk-root .pika-select {
  display: inline-block;
  *display: inline;
}
.bk-root .pika-table {
  width: 100%;
  border-collapse: collapse;
  border-spacing: 0;
  border: 0;
}
.bk-root .pika-table th,
.bk-root .pika-table td {
  width: 14.285714285714286%;
  padding: 0;
}
.bk-root .pika-table th {
  color: #999;
  font-size: 12px;
  line-height: 25px;
  font-weight: bold;
  text-align: center;
}
.bk-root .pika-button {
  cursor: pointer;
  display: block;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  outline: none;
  border: 0;
  margin: 0;
  width: 100%;
  padding: 5px;
  color: #666;
  font-size: 12px;
  line-height: 15px;
  text-align: right;
  background: #f5f5f5;
}
.bk-root .pika-week {
  font-size: 11px;
  color: #999;
}
.bk-root .is-today .pika-button {
  color: #33aaff;
  font-weight: bold;
}
.bk-root .is-selected .pika-button,
.bk-root .has-event .pika-button {
  color: #fff;
  font-weight: bold;
  background: #33aaff;
  box-shadow: inset 0 1px 3px #178fe5;
  border-radius: 3px;
}
.bk-root .has-event .pika-button {
  background: #005da9;
  box-shadow: inset 0 1px 3px #0076c9;
}
.bk-root .is-disabled .pika-button,
.bk-root .is-inrange .pika-button {
  background: #D5E9F7;
}
.bk-root .is-startrange .pika-button {
  color: #fff;
  background: #6CB31D;
  box-shadow: none;
  border-radius: 3px;
}
.bk-root .is-endrange .pika-button {
  color: #fff;
  background: #33aaff;
  box-shadow: none;
  border-radius: 3px;
}
.bk-root .is-disabled .pika-button {
  pointer-events: none;
  cursor: default;
  color: #999;
  opacity: .3;
}
.bk-root .is-outside-current-month .pika-button {
  color: #999;
  opacity: .3;
}
.bk-root .is-selection-disabled {
  pointer-events: none;
  cursor: default;
}
.bk-root .pika-button:hover,
.bk-root .pika-row.pick-whole-week:hover .pika-button {
  color: #fff;
  background: #ff8000;
  box-shadow: none;
  border-radius: 3px;
}
.bk-root .pika-table abbr {
  border-bottom: none;
  cursor: help;
}
.bk-root .bk-widget-box {
  overflow: visible;
  padding: 5px 10px;
}
.bk-root .bk-widget label {
  margin-bottom: 2px;
}
.bk-root .bk-widget {
  margin-top: 10px;
}
.bk-root .bk-widget h1:first-child,
.bk-root .bk-widget h2:first-child,
.bk-root .bk-widget h3:first-child,
.bk-root .bk-widget h4:first-child,
.bk-root .bk-widget h5:first-child,
.bk-root .bk-widget h6:first-child,
.bk-root .bk-widget p:first-child {
  /* This ensures that the top of the item is at the top of box in common text cases that */
  /* get browser styling */
  margin-top: 0;
}
.bk-root .bk-widget-form-input {
  display: block;
  height: 31px;
  padding: 0 12px;
  background-color: #fff;
  background-image: none;
  border: 1px solid #ccc;
  border-radius: 4px;
}
.bk-root .bk-widget-form-input:focus {
  border-color: #66afe9;
  outline: 0;
  -webkit-box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
  box-shadow: inset 0 1px 1px rgba(0,0,0,.075), 0 0 8px rgba(102, 175, 233, 0.6);
}
.bk-root .bk-widget-form-input::-moz-placeholder {
  color: #999999;
  opacity: 1;
}
.bk-root .bk-widget-form-input:-ms-input-placeholder {
  color: #999999;
}
.bk-root .bk-widget-form-input::-webkit-input-placeholder {
  color: #999999;
}
.bk-root .bk-widget-form-input[disabled],
.bk-root .bk-widget-form-input[readonly],
fieldset[disabled] .bk-root .bk-widget-form-input {
  cursor: not-allowed;
  background-color: #eeeeee;
  opacity: 1;
}
textarea.bk-root .bk-widget-form-input {
  height: auto;
}
.bk-root .bk-widget button {
  min-width: 100%;
}
.bk-root .bk-widget input[type="text"] {
  min-width: 90%;
}
.bk-root .bk-widget select {
  min-width: 97%;
}
.bk-root .bk-bs-dropdown-toggle .bk-bs-caret {
  margin-left: 5px;
}
.bk-root .bk-bs-dropdown-menu {
  width: 100%;
}
.bk-root .bk-bs-nav-tabs {
  overflow: hidden;
}
.bk-root .bk-bs-tab-pane {
  float: left;
}
.bk-root .bk-slider label {
  margin-right: 5px;
}
.bk-root .bk-slider .bk-slider-value {
  display: inline-block;
  font-weight: 600;
}
.bk-root .bk-slider input,
.bk-root .bk-slider .bk-slider-value {
  margin-bottom: 5px;
}

/*# sourceMappingURL=bokeh-widgets.css.map */
