''' Provides different ways for Bokeh applications to modify Bokeh
Documents when sessions are created.

'''
from __future__ import absolute_import

from .handler import *
from .function import *
from .notebook import *
from .script import *
from .server_lifecycle import *
from .directory import *
